Module graticule

Module graticule 

Structs

GraticuleLineSegments
Represents all graticule lines for vectorized rendering
GraticulePolyline
Represents a polyline in normalized Mollweide coordinates [0,1]
GraticuleTransform
Transform graticule coordinates through coordinate systems and view rotation

Functions

render_graticule_cairo
Render vectorized graticule lines to a Cairo context (for PDF output)
render_graticule_cairo_with_color
Render graticule lines with custom color
render_graticule_hammer_vectorized
Generate vectorized graticule lines for Hammer-Aitoff projection
render_graticule_mollweide
Render graticule lines (meridians and parallels) for a given coordinate system
render_graticule_mollweide_vectorized
Generate vectorized graticule lines for Mollweide projection