Functions
- compute_
gnomonic_ scale - Compute scale limits for gnomonic projections using only FOV-contained pixels. This ensures the color scale is based on visible data, not the entire map.
- plot_
gnomonic_ auto - Plot gnomonic projection with automatic format detection
- plot_
gnomonic_ pdf - Plot a gnomonic projection to PDF
- plot_
gnomonic_ png - Plot a gnomonic projection to PNG